/* 
 *  _fileops.h
 *
 *  Small inline functions and macros
 */

#ifndef __LNFC_FILEOPS_H
#define __LNFC_FILEOPS_H

#if (defined(__linux__)) && !defined(__UNIX__)
#  define __UNIX__ 1
#endif

#if defined(_WIN32) || defined(__OS2__) || defined(__MSDOS__)
#  define FILE_SEPARATOR      '\\'
#  define FILE_SEPARATOR_STR  "\\"
#  define PATH_SEPARATOR      ';'
#  define PATH_SEPARATOR_STR  ";"
#elif defined(__UNIX__)
#  define FILE_SEPARATOR      '/'
#  define FILE_SEPARATOR_STR  "/"
#  define PATH_SEPARATOR      ':'
#  define PATH_SEPARATOR_STR  ":"
#else
#  error FILE_SEPARATOR and PATH_SEPARATOR are host-dependent
#endif


#if defined(__cplusplus)
#define LNFC_INLINE inline
#else
#define LNFC_INLINE static
#endif


#include <sys/types.h>  // S_ISDIR()
#include <sys/stat.h>   // stat()


/*-------------------------------------------------------------------*/


LNFC_INLINE int is_directory(const char *filepath)
{
    struct stat statbuf;

    if (stat(filepath, &statbuf) < 0)
        return false;

    return S_ISDIR(statbuf.st_mode);
}


/*-------------------------------------------------------------------*/


LNFC_INLINE int is_absolute(const char *filepath)
{
     if (!filepath || !filepath[0])
         return 0;

#if defined(_WIN32) || defined(__OS2__) || defined(__MSDOS__)

     if (filepath[0] == FILE_SEPARATOR)
         return 1;
     if (filepath[1] == ':')
         return 1;

#elif defined(__UNIX__)

     if (filepath[0] == FILE_SEPARATOR)
         return 1;

#else

#    error Absolute path is host-dependent thing and must be implemented now

#endif

    return 0;

} /* is_absolute */


#undef LNFC_INLINE

#endif  /* __LNFC_FILEOPS_H */

/* EOF */
