/*
 *  _lnfc.h  --  part of LNFC library
 *
 *  PURPOSE:
 *    This file must be included AFTER headers of standard C API
 *    (otherwise, causes compile errors under Borland C++)
 *    and BEFORE any header of Notes API.
 *
 *  Used internally by LNFC only, not by user application,
 *  because user application uses LNFC wrapper and not requires Notes API ;)
 *
 *  Written by Evseev at Jun 2001
 */

#ifndef __PREDEFS_H
#define __PREDEFS_H


//-------------------------------------------------------------
//
//  Platform detection macros
//
//  This must be BEFORE NotesAPI includes because NotesAPI requires W32 define
//

#if defined(_WIN32)
#  if !defined(W32)
#    define W32  1            /* required by NotesAPI */
#    define WINDOWS_INCLUDED  /* workaround for NotesAPI global.h */
#  endif
#  if !defined(__CONSOLE__) && !defined(__GUI__)
#    define __CONSOLE__ 1
#  endif
#  if defined(__CONSOLE__) && !defined(__WIN32_COMSOLE__)
#    define __WIN32_CONSOLE__ 1   /* my own macro */
#  endif
#elif defined(__linux__)
#  define LINUX  1            /* required by NotesAPI too */
#  define UNIX   1
#endif 


//---------------------------------------------------------------------
//
//  Lotus datatypes.
//  Must be included AFTER standard C headers,
//  but BEFORE windows.h because types/defines conflict
//
 
#include <global.h>


//---------------------------------------------------------------------
//
//  Error checking for members of Notes_object child's
//
//  These macros cannot be implemented as inline functions,
//  so, use old good #define's
//

//
//  Check state of another object.
//  If it's bad, set self in the same state and return error
//
#define RETURN_IF_BAD(__another_object) \
        do { \
            int i = __another_object->get_last_error(); \
            if (i < 0) { \
                reset(i); \
                return i; \
            } \
        } while(0)

//
//   Terminate caller, if object is in erroneous state
//
#define RETURN_IF_ERROR() \
        do { if (bad()) return last_error; } while(0)

//
//   Terminate caller, if object has no associated Notes handle     
//
#define RETURN_IF_NULL_HANDLE() \
        do { if (!handle) RETURN_API_ERROR(ERR_HDL_NULL); } while(0)

//
//   Inspire termination of caller with given error code (saved to last_error)
//   Don't check that new value is actually erroneous (don't calls bad())
//
#define RETURN_API_ERROR(__api_error_code) \
        return last_error = status2int(__api_error_code)

//
//   Call NotesAPI routine.
//   Save result to last_error.
//   Terminate caller, if error occured.
//
#define RETURN_IF_API_ERROR(__notes_api_call) \
        do { \
            last_error = status2int(__notes_api_call); \
            if (bad()) return last_error; \
        } while(0)

//
//   Call NotesAPI routine.
//   On error terminates caller WITHOUT setting 'last_error'.
//
#define __RETURN_IF_API_ERROR(__notes_api_call) \
        do { \
            STATUS status = __notes_api_call; \
            if (status != NOERROR) return status2int(status); \
        } while(0)


//
//   For objects owned by database: documents, ACLs, etc.
//   Check database is good and opened; try to open; check ok
//
#define RETURN_IF_DB_ISNOT_READY() \
        do {                       \
            RETURN_IF_BAD(db);     \
            if (!db->is_open()) {  \
                db->open();        \
                /* RETURN_API_ERROR(ERR_DB_NOT_OPEN); */ \
            }                      \
            RETURN_IF_BAD(db);     \
        } while(0)



#endif  /* ifndef __PREDEFS_H */

/* EOF */
