//
//  abooks.cpp  --  part of LNFC library
//
//  Implementation of class Address_books
//
//  Written by Evseev at Jun 2001
//

#include "abooks.h"
#include "database.h"    
#include "document.h"
#include "formula.h"

#include "_vector.h"  // must be before global.h (included via _lnfc.h),
                      // otherwise causes compilation errors under BC++ 5.5
#include "_lnfc.h"

#include <osmem.h>    // OSLock, OSUnlock, OSMemFree
#include <oserr.h>    // ERR_OS_HANDLE_RANGE
#include <lookup.h>   // NAMEGetAddressBooks
#include <niferr.h>   // ERR_USER_NOT_FOUND


__LNFC_NAMESPACE_BEGIN__


class Address_books_d : public Address_books_i
{

protected:

    friend Address_books;

    Address_books_d(bool open_now = true)     { if (open_now) setup();  }
    Address_books_d(const Notes_name &server) { setup(server->plain()); }

    virtual ~Address_books_d() { }

    virtual Document lookup_by_lastname(
        const Notes_string &person_lastname,
        bool must_be_opened_immedately = true);

    Database at(size_t index);

    size_t get_count();

protected:

    virtual int setup(char *server_name = 0);

    vector<Database> abooks;

};

//---------------------------------------------------------------------


Address_books::Address_books(bool open_now)
  : SmPtr(new Address_books_d(open_now))
{ }
                   
Address_books::Address_books(const Notes_name &server)
  : SmPtr(new Address_books_d(server))
{ }


//---------------------------------------------------------------------


Database Address_books_d::at(size_t index)
{
    if (index >= abooks.size())
        return Database::none(ERR_OS_HANDLE_RANGE);
    return abooks.at(index);
}


size_t Address_books_d::get_count() {
    setup();
    return abooks.size();
}


Document Address_books_d::lookup_by_lastname(
    const Notes_string &person_lastname, bool must_be_opened_immediately)
{
    setup();

    int i, books_count = abooks.size();
    for (i = 0; i < books_count; i++) {
        Database &db = abooks[i];
        if (!db->is_open())
            db->open();
        Document doc = db->first_matching(
            "Lastname = \"" + person_lastname + "\"",
            must_be_opened_immediately);
        if (doc->exist())
            return doc;
    }

    return Document::none(ERR_USER_NOT_FOUND);
}


int Address_books_d::setup(char *server_name)
{
    if (handle)   // prevent multiple calling
        return 0;

    WORD i, nbooks;
    WORD namelen, buflen;
    HANDLE htmp;

    RETURN_IF_API_ERROR(
        NAMEGetAddressBooks( 
            server_name,
            0,   // wOption, may be NAME_GET_AB_TITLES | NAME_DEFAULT_TITLES
            &nbooks,
            &buflen,
            &htmp));

    // pseudo-handle indicies that setup is succesfully passed
    handle = (notes_handle_t) true;

    char *abnames = OSLock(char, htmp);

    for (i = 0; i < nbooks; i++) {
        namelen = strlen(abnames);
        Database db(nSTR abnames, Dont_open);
        // abooks.push_back: we pass pointer to Database_d,
        // so Database::Database(Database_d*) will be invoked
        abooks.push_back(db);  
        abnames += namelen + 1;
    }

    OSUnlock(htmp);
    OSMemFree(htmp);

    return 0;
}


__LNFC_NAMESPACE_END__

// EOF
