//
//  abooks_test.cpp  --  optional part of LNCPP library
//
//  Testing sample for Address_books class
//

#include "abooks.h"

#include "document.h"
#include "field.h"
#include "directory.h"

#include "nsession.h"   // also includes fstream.h

__LNFC_NAMESPACE__

int main(int argc, const char *argv[])
{
    if (argc != 2) {
        cout << "Usage: prog.exe lastname_of_user " << endl;
        return 1;
    }

    INIT_NOTES_RUNTIME();

    Address_books abooks;

    size_t i, count = abooks->get_count();

    for (i = 0; i < count; i++) {
        Database db = abooks[i];
        cout << (i+1) << " = \"" << db->getpath()->readable() << "\"" << endl;
    }

    Document doc = abooks->lookup_by_lastname(argv[1]);

    cout << doc->error_string("After lookup") << endl;
     
    if (doc->exist()) {
        
        Field f(doc, "DeploymentServers");
        if (f->exist()) {
            cout << "DeploymentServers = " << f->text()->readable() << endl;
        } else {
            cout << "DeploymentServers field not found" << endl;
        }

        Directory dir(doc);
        cout << "User directory: " << dir->getpath()->readable()
             << (dir->exist() ? " exist" : " not exist") << endl;

    }

    return 0;
}

// EOF
