//
//  adminrq.cpp  --  part of LNFC library
//
//  Implementation of class Admin_requests
//
//  Written by Evseev at Jul 2001
//

#include "adminrq.h"

#include "_lnfc.h"

#include <nsferr.h>   // ERR_HDL_NULL, used by RETURN_IF_NULL_HANDLE()
#include <nsfdata.h>  // DBHANDLE, DBREPLICAINFO
#include <nsfdb.h>    // NSFDbReplicaInfoGet()
#include <kfm.h>      // HCERTIFIER, required by adminp.h
#include <adminp.h>


Admin_requests_d::Admin_requests_d()
  : Database_d(nSTR "admin4.nsf", Dont_open)  // what for v5 ???
{
}


int Admin_requests_d::new_replica(
    const Database &db,
    const Notes_name &dest_server)
{
    RETURN_IF_ERROR();
    if (!is_open()) open();
    RETURN_IF_ERROR();
    RETURN_IF_NULL_HANDLE();

    ADMINReqParams arp;
    arp.Flags = 0;
    DBREPLICAINFO replica_info;

    if (!db->is_open() && (db->open() < 0))
        db->reset();

    if (db->is_open())
        NSFDbReplicaInfoGet ((DBHANDLE)db->get_handle(), &replica_info);

    Notes_string filepath = db->getpath()->filepath();
    Notes_string author = Notes_name::current();
    Notes_string from_server = db->getpath()->server();
    if (from_server->is_empty())
        from_server = author;

    RETURN_IF_API_ERROR(
        ADMINReqChkAccessNewReplica(
            (DBHANDLE)handle,          // handle of Admin Requests database
            author->plain(),           // who is author of request
            from_server->plain(),      // from which server
            filepath->plain(),         // from which file
            db->get_title()->plain(),  // db title, saved to ProxyNameList field
            &replica_info,             // db replica info
            dest_server->abbreviated()->plain(), // to which server
            filepath->plain(),                   // to which file
            &arp,                      // admin requests params
            sizeof(arp)
    )   );

    return 0;
}


// EOF //
