//
//  adrbook.h  --  part of LNFC library
//
//  Declaration of classes Address_book, Address_book_d,
//      Personal_address_book, Personal_address_book_d
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_ADRBOOK_H
#define __LNFC_ADRBOOK_H


#ifndef __LNFC_DATABASE_H
#include "database.h"
#endif


__LNFC_NAMESPACE_BEGIN__


// forward references //
class Address_book;
class Personal_address_book;

class Database_path;
class Directory;


//---------------------------------------------------------------------


class Address_book_d : public Database_d
{

protected:

    friend Address_book;

    Address_book_d(const Database_path &dbpath,
                   bool must_be_immediately_opened = true)
      : Database_d(dbpath, must_be_immediately_opened)
    { }

    Address_book_d(notes_handle_t active_handle, const Database_path &dbpath)
      : Database_d(active_handle, dbpath)
    { }

    Address_book_d(const Database_d &db)
      : Database_d(db)
    { }

};


//---------------------------------------------------------------------


class Address_book : public Smart_pointer2<Database, Address_book_d>
{

public:

    Address_book(const Database &db)
      : SmPtr2(reinterpret_cast<Address_book_d*>(&*db))
    { }

    Address_book(const Database_path &dbpath, bool open_now = true)
      : SmPtr2(new Address_book_d(dbpath, open_now))
    { }

protected:

    //* Address_book(Address_book_d *abook_addr)
    //*   : SmPtr2(abook_addr)
    //* { }

};


//---------------------------------------------------------------------


class Personal_address_book_d : public Address_book_d
{

protected:

    friend Personal_address_book;

    Personal_address_book_d(const Directory &userdir, bool open_now = true);

};


//---------------------------------------------------------------------


class Personal_address_book
  : public Smart_pointer2<Address_book, Personal_address_book_d>
{

public:

    Personal_address_book(const Directory &userdir, bool open_now = true);

    Personal_address_book(const Database &db)
      : SmPtr2(reinterpret_cast<Personal_address_book_d*>(&*db))
    { }
};


//---------------------------------------------------------------------

__LNFC_NAMESPACE_END__

#endif  // __LNFC_ADRBOOK_H

// EOF //
