#
#  Makefile  --  part of LNFC library
#
#  Rules for building LNFC using Borland C++ 5.5 under Win32
#
#  Written at Jun 2001 by Evseev
#

CC = bcc32
CPPFLAGS = -v -y -w-pck -IC:\Lotus\NotesAPI.462\Include -x- -D_RWSTD_NO_EXCEPTIONS

LD = bcc32
LDFLAGS  = -v -y

.cpp.obj:
	$(CC) -c $(CPPFLAGS) $&.cpp

test : nstring_test.exe \
       dbpath_test.exe \
       database_test.exe \
       document_test.exe \
       formula_test.exe \
       field_test.exe \
       directory_test.exe \
       adrbook_test.exe \
       abooks_test.exe

lib :  nobject.obj \
       nstring.obj \
       nname.obj \
       dbpath.obj \
       database.obj \
       document.obj \
       timedate.obj \
       field.obj \
       formula.obj \
       adrbook.obj \
       abooks.obj \
       location.obj \
       adminrq.obj \
       acl.obj \
       notesini.obj \
       directory.obj \
       view.obj
	tlib lnfc /P32 @&&|
-+nsession &
-+nobject &
-+nstring &
-+nname &
-+dbpath &
-+database &
-+document &
-+timedate &
-+field &
-+formula &
-+adrbook &
-+abooks &
-+location &
-+adminrq &
-+acl &
-+notesini &
-+directory &
-+view
|

clean:
	del *.obj
	del *.tds
	del *.tr2

cleanall: clean
	del *.exe

LIB_H = _lnfc.h
TST_H = nsession.h

LNFCDEFS_H = lnfcdefs.h smartptr.h

NOBJECT_H         = nobject.h   $(LNFCDEFS_H) _cstring.h bitricks.h
nobject.obj       : nobject.cpp $(NOBJECT_H)
NOBJECT_OBJ       = nobject.obj
                  
nsession.obj      : nsession.cpp nsession.h $(LIB_H)

NSTRING_H         = nstring.h         $(LNFCDEFS_H) _cstring.h
ALL_NSTRING_H     = $(NSTRING_H) nname.h dbpath.h
nstring.obj       : nstring.cpp         $(ALL_NSTRING_H) $(LIB_H) 
nstring_test.obj  : nstring_test.cpp    $(ALL_NSTRING_H) $(TST_H) 
NSTRING_OBJ       = nstring.obj nsession.obj
nstring_test.exe  : nstring_test.obj  $(NSTRING_OBJ)
	$(LD) $(LDFLAGS) $**

NNAME_H           = nname.h           $(NSTRING_H)
nname.obj         : nname.cpp           $(NNAME_H)     $(LIB_H)
nname_test.obj    : nname_test.cpp      $(NNAME_H)     $(TST_H)
NNAME_OBJ         = nname.obj         $(NSTRING_OBJ)
nname_test.exe    : nname_test.obj      $(NNAME_OBJ)
	$(LD) $(LDFLAGS) $**
                                               
DBPATH_H          = dbpath.h          $(NNAME_H)
dbpath.obj        : dbpath.cpp          $(DBPATH_H)    $(LIB_H)     
dbpath_test.obj   : dbpath_test.cpp     $(DBPATH_H)    $(TST_H)     
DBPATH_OBJ        = dbpath.obj        $(NNAME_OBJ)
dbpath_test.exe   : dbpath_test.obj     $(DBPATH_OBJ)
	$(LD) $(LDFLAGS) $**
          
DATABASE_H        = database.h        $(DBPATH_H)
database.obj      : database.cpp        $(DATABASE_H)  $(LIB_H)   
database_test.obj : database_test.cpp   $(DATABASE_H)  $(TST_H)   
DATABASE_OBJ      = database.obj      $(DBPATH_OBJ)       nobject.obj
database_test.exe : database_test.obj   $(DATABASE_OBJ)
	$(LD) $(LDFLAGS) $**
        
DOCUMENT_H        = document.h        $(DATABASE_H)
document.obj      : document.cpp        $(DOCUMENT_H)  $(LIB_H)   
document_test.obj : document_test.cpp   $(DOCUMENT_H)  $(TST_H) formula.h field.h
DOCUMENT_OBJ      = document.obj      $(DATABASE_OBJ)
document_test.exe : document_test.obj   $(DOCUMENT_OBJ)   formula.obj field.obj
	$(LD) $(LDFLAGS) $**
        
TIMEDATE_H        = timedate.h
timedate.obj      : timedate.cpp        $(TIMEDATE_H)  $(LIB_H)
timedate_test.obj : timedate_test.cpp   $(TIMEDATE_H)  $(TST_H)
TIMEDATE_OBJ      = timedate.obj
timedate_test.exe : timedate_test.obj   $(TIMEDATE_OBJ) nsession.obj
	$(LD) $(LDFLAGS) $**

FIELD_H           = field.h           $(DOCUMENT_H)
field.obj         : field.cpp           $(FIELD_H)     $(LIB_H)      
field_test.obj    : field_test.cpp      $(FIELD_H)     $(TST_H)      
FIELD_OBJ         = field.obj         $(DOCUMENT_OBJ) timedate.obj
field_test.exe    : field_test.obj      $(FIELD_OBJ)  formula.obj
	$(LD) $(LDFLAGS) $**
         
FORMULA_H         = formula.h         $(NOBJECT_H)
formula.obj       : formula.cpp         $(FORMULA_H)   $(LIB_H)    
formula_test.obj  : formula_test.cpp    $(FORMULA_H)   $(TST_H)  $(DOCUMENT_H)
FORMULA_OBJ       = formula.obj       $(DATABASE_OBJ)
formula_test.exe  : formula_test.obj    $(FORMULA_OBJ)           document.obj
	$(LD) $(LDFLAGS) $**
       
ABOOKS_H          = abooks.h          $(DOCUMENT_H)
abooks.obj        : abooks.cpp          $(ABOOKS_H) $(LIB_H) formula.h   _vector.h
abooks_test.obj   : abooks_test.cpp     $(ABOOKS_H) $(TST_H)   field.h    directory.h
ABOOKS_OBJ        = abooks.obj        $(DOCUMENT_OBJ)        formula.obj
abooks_test.exe   : abooks_test.obj     $(ABOOKS_OBJ)          field.obj  directory.obj
	$(LD) $(LDFLAGS) $**
                                 
DIRECTORY_H        = directory.h      $(DATABASE_H)
directory.obj      : directory.cpp      $(DIRECTORY_H) $(LIB_H) $(FIELD_H) _fileops.h itemtbl.c
directory_test.obj : directory_test.cpp $(DIRECTORY_H) $(TST_H)
DIRECTORY_OBJ      = directory.obj    $(DATABASE_OBJ)
directory_test.exe : directory_test.obj $(DIRECTORY_OBJ) document.obj field.obj
	$(LD) $(LDFLAGS) $**
                                               
ADRBOOK_H         = adrbook.h         $(DATABASE_H)
adrbook.obj       : adrbook.cpp         $(LIB_H) $(ADRBOOK_H) $(FIELD_H) $(DIRECTORY_H)
adrbook_test.obj  : adrbook_test.cpp    $(TST_H) $(ADRBOOK_H) $(FIELD_H) $(DIRECTORY_H)
ADRBOOK_OBJ       = adrbook.obj       $(DIRECTORY_OBJ) field.obj document.obj
adrbook_test.exe  : adrbook_test.obj    $(ADRBOOK_OBJ) abooks.obj formula.obj 
	$(LD) $(LDFLAGS) $**

LOCATION_H        = location.h        $(DOCUMENT_H)
location.obj      : location.cpp        $(LIB_H) $(LOCATION_H) adrbook.h formula.h
                                               
NOTESINI_H        = notesini.h        $(NOBJECT_H) nstring.h
notesini.obj      : notesini.cpp        $(LIB_H) $(NOTESINI_H) field.h $(LOCATION_H) directory.h
NOTESINI_OBJ      : notesini.obj      $(FIELD_OBJ) location.obj directory.obj

ADMINRQ_H         = adminrq.h         $(DATABASE_H)
adminrq.obj       : adminrq.cpp         $(LIB_H) $(ADMINRQ_H)
adminrq_test.obj  : adminrq_test.cpp    $(TST_H) $(ADMINRQ_H)
ADMINRQ_OBJ       = adminrq.obj       $(DATABASE_OBJ)
adminrq_test.exe  : adminrq_test.obj    $(ADMINRQ_OBJ)
	$(LD) $(LDFLAGS) $**

ACL_H             = acl.h             $(DATABASE_H)
acl.obj           : acl.cpp             $(LIB_H) $(ACL_H)
acl_test.obj      : acl_test.cpp        $(TST_H) $(ACL_H)
ACL_OBJ           = acl.obj           $(DATABASE_OBJ)
acl_test.exe      : acl_test.obj        $(ACL_OBJ)
	$(LD) $(LDFLAGS) $**

VIEW_H            = view.h            $(FIELD_H)
view.obj          : view.cpp            $(LIB_H) $(VIEW_H)
view_test.obj     : view_test.cpp       $(TST_H) $(VIEW_H)
VIEW_OBJ          = view.obj          $(FIELD_OBJ)
view_test.exe     : view_test.obj       $(VIEW_OBJ)
	$(LD) $(LDFLAGS) $**

DBCAT_H           = dbcat.h           $(DATABASE_H)
                                      
NOTESINI_H        = notesini.h        $(NOBJECT_H)
                                      
USER_ID_H         = user_id.h         $(NOBJECT_H)

lnfc_test.obj     : lnfc_test.cpp  $(LNFC_H)
                                   
migrate.obj       : migrate.cpp    $(LNFC_H)
