/*
 *  bitricks.h  --  part of LNFC library
 *
 *  Low-level routines and macros for bit manipulations ("bit tricks").
 *
 *  It's recommended to include me AFTER windows.h and other things where
 *  HIWORD/LOWORD are defined too, for prevention preprocessing-time conflicts.
 *
 *  Written by Evseev at Jun 2001
 */

#ifndef __BITRICKS_H
#define __BITRICKS_H


/*  Under C++ we use inline routines,
 *  under Windows we use macros from Windef.h
 */
#if !defined(__cplusplus) && !defined(_WIN32)

#ifndef MKDWORD(x,y)
#define MKDWORD(x,y) ((((unsigned long)(x)) << 16) | (y))
#endif

#ifndef HIWORD(x)
#define HIWORD(x) ((unsigned short)(((x) >> 16) & 0xFFFF))
#endif

#ifndef LOWORD(x)
#define LOWORD(x) ((unsigned short)((x) & 0xFFFF))
#endif

#endif  /* !defined(__cplusplus) && !defined(_WIN32) */


#if defined(__cplusplus)

template<typename T> inline int
msb_pos() {
    return sizeof(T) * 8 - 1;
}

template<typename T> inline T
msb_mask() {
    return ((T)1) << msb_pos<T>();
}

template<typename T> inline T
max_possible_unsigned() {
    return T(-1);
}

template<typename T> inline T
max_possible_signed() {
    return T(-1) >> 1;
}

inline unsigned long
mkdword(unsigned short hiword, unsigned short loword) {
    return (((unsigned long)hiword) << 16) | loword;
}

inline unsigned int
hiword(unsigned long value) {
    return (value >> 16) & 0xFFFF;
}

inline unsigned int
loword(unsigned long value) {
    return value & 0xFFFF;
}

#endif


#endif  /* __BITRICKS_H */
