/* check_db.c */

#if defined(_WIN32)
#  if !defined(W32)
#    define W32  1            /* required by NotesAPI */
#    define WINDOWS_INCLUDED  /* workaround for NotesAPI global.h */
#  endif
#  if !defined(__CONSOLE__) && !defined(__GUI__)
#    define __CONSOLE__ 1
#  endif
#  if defined(__CONSOLE__) && !defined(__WIN32_COMSOLE__)
#    define __WIN32_CONSOLE__ 1   /* my own macro */
#  endif
#elif defined(__linux__)
#  define LINUX  1            /* required by NotesAPI too */
#  define UNIX   1
#endif 

#include <global.h>
#include <nsfdb.h>
#include <osmisc.h>

#include <stdio.h>

#define IF_BAD(_Action, _Hint) \
	if (((status = (_Action)) != NOERROR) && report_error(status, _Hint))

STATUS report_error(STATUS status, const char *hint)
{
	char s[256];
	OSLoadString(NULLHANDLE, ERR(status), s, sizeof(s)-1);
	printf("Cannot %s: %s\n", hint, s);
	return status;
}

int check_db(char *fname)
{
	DBHANDLE dbhandle;
	STATUS status;
	printf("Try database: %s...\n", fname);
	IF_BAD (NSFDbOpen(fname, &dbhandle), "open")
		return -1;
	printf("...open OK\n");
	IF_BAD (NSFDbClose(dbhandle), "close")
		return -1;
	printf("...close OK\n");
	return 0;
}

int main(int argc, char *argv[])
{
	//STATUS status = NotesInitExtended(argc, argv);
	STATUS status = NotesInit();
	int i;
	if (status != NOERROR) {
		printf("Cannot initialize Notes: error 0x%x\n", status);
		return 1;
	}
	printf("Notes initialized...\n");
	for (i = 1; i < argc; i++) {
		check_db(argv[i]);
	}
	NotesTerm();
	printf("Notes terminated, done.\n");
	return 0;
}

/* EOF */
