//
//  database_test.cpp  --  appendix part of LNFC library
//
//  Testing sample for Database class
//

#include <stdlib.h>  // exit()

#include "nsession.h"    // also includes fstream.h

#include "database.h"

__LNFC_NAMESPACE__


void check_argc(int actual_argc, int required_args_count, const char *hint)
{
    if (actual_argc - 2 >= required_args_count)
        return;
    cout << "Missing args: " << hint << endl;
    exit(1);
}



int main(int argc, const char *argv[])
{
    INIT_NOTES_RUNTIME();

    if (argc < 2) {
        cout << "Syntax: myname.exe {1,2,3} ..." << endl;
        return 1;
    }

    switch (argv[1][0]) {
    
    case '1': { 
        cout << "Open database with given filename" << endl;
        check_argc(argc, 1, "database_filename");
        
        Database db1(dbPATH argv[2]);
        cout << db1->getpath()->readable()
             << (db1->exist() ? " ok" : " bad") << endl;
        
        break;
    }
    
    case '2': {
        cout << "Open database with given filename on given server" << endl;
        check_argc(argc, 2, "database_filename server_name");

      //Database db1(Database_path(nSTR argv[2], nNAMESTR argv[3]));
        Database db1(Database_path(Notes_string(argv[2]), Notes_name(argv[3])));
        cout << db1->getpath()->c_str() << (db1->exist() ? " ok" : " bad") << endl;
        
        break;
    }

    case '3': {
        cout << "Create empty database, then remove it" << endl;
        check_argc(argc, 1, "database_filename");

        Database z1(dbPATH argv[2]);
        z1->create(Dont_force); cout << z1->error_string("create(Dont_force)") << endl;
        z1->create(Force);      cout << z1->error_string("create(Force)     ") << endl;
        z1->remove();           cout << z1->error_string("remove()          ") << endl;
        
        break;
    }

    case '4': {
        cout << "Create database from template" << endl;
        check_argc(argc, 2, "database_filename template_filename");

        Database z2(dbPATH argv[2]);
        z2->create(dbPATH argv[3], Force);
        cout << z2->error_string("Create(Force)") << endl;

        break;
    }

    case '5': {
        cout << "Create copy of existing database" << endl;
        check_argc(argc, 2, "existing_database_filename new_database_filename");

        Database z3(dbPATH argv[3]);
        z3->create_copy_from(Database(dbPATH argv[2], Dont_open), Dont_force);
        cout << z3->error_string("Create copy") << endl;
      
        break;
    }

    case '6': {
        cout << "Create replica of existing database" << endl;
        check_argc(argc, 2, "existing_database_filename new_database_filename");

        Database z4(dbPATH argv[3], Dont_open);
        z4->create_replica_from(Database(dbPATH argv[2], Dont_open), Force);
        cout << z4->error_string("Create replica") << endl;
      
        break;
    }

    default: {
        cout << "Invalid arg #1, must be 1..6" << endl;

        //int create_replica_to(const Notes_name &server_name);
        //virtual int open();
        //virtual int close(bool force = false);
    }

    }  // switch
    return 0;
}


// EOF //
