//
//  dbpath.cpp  --  part of LNFC library
//
//  Implementation of class Database_path_d
//
//  Written by Evseev at Jul 2001
//

#include "dbpath.h"
#include "nname.h"

#include "_fileops.h"

#include "_lnfc.h"

#include <names.h>      // MAXPATH
#include <osfile.h>     // OSPathNetParse
#include <osenv.h>      // OSGetEnvironmentString


//---------------------------------------------------------------------


Database_path_d::Database_path_d(
    const Notes_string *const filepath_addr,
    const Notes_name   *const servername_addr,
    const Notes_string *const portname_addr)
  :
    Notes_string_d(
          (filepath_addr ? (  *filepath_addr)->length()     : 0) +
        (servername_addr ? (*servername_addr)->length() + 2 : 0) +
          (portname_addr ? (  *portname_addr)->length() + 3 : 0) + 1)
{
    char result[MAXPATH];
    char empty[] = "";  // stupid trick for GCC
    if (NOERROR == OSPathNetConstruct(
        (  !portname_addr || (  *portname_addr)->is_empty()) ? NULL : (  *portname_addr)->plain(),
        (!servername_addr || (*servername_addr)->is_empty()) ? empty: (*servername_addr)->plain(),
        (  !filepath_addr || (  *filepath_addr)->is_empty()) ? empty: (  *filepath_addr)->plain(),
        result))
    {
        replace(0, length(), result, strlen(result));
    } else {
        replace(0, length(), "", 1);
    }
}


Notes_name Database_path_d::server()
{
    char srvname[MAXPATH];
    return Notes_name(
        Notes_string((OSPathNetParse(plain(), NULL, srvname, NULL) == NOERROR)
            ? srvname : "", Skip_lmbcs_conversion));
}


Database_path Database_path_d::filepath()
{
    char fname[MAXPATH];
    return Database_path(
        Notes_string((OSPathNetParse(plain(), NULL, NULL, fname) == NOERROR)
            ? fname : "", Skip_lmbcs_conversion));
}


Notes_string Database_path_d::port()
{
    char port[MAXPATH];
    return Notes_string((OSPathNetParse(plain(), port, NULL, NULL) == NOERROR)
        ? port : "", Skip_lmbcs_conversion);
}


Notes_string Database_path_d::absolute()
{
    if (is_remote())                  // remote name cannot be absolute
        return Database_path(this);

    Database_path fpath = filepath(); // check local name already in absolute form
    if (!fpath->is_empty() > 0) {
        if (is_absolute(fpath->native().c_str()))
            return fpath;
    }

    char buff[MAXENVVALUE];           // convert local name to absolute form
    if (!OSGetEnvironmentString("Directory", buff, sizeof(buff)))
        return fpath;
    if (fpath->is_empty())
        return Notes_string(buff);
    return Notes_string(buff) + FILE_SEPARATOR_STR + fpath;
}


// EOF //
