//
//  dbpath.h  --  part of LNFC library
//
//  Declaration of class Database_path, Database_path_d
//  (note: these classes are implemented in nstring.cpp, not in dbpath.cpp)
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_DBPATH_H
#define __LNFC_DBPATH_H


#ifndef __LNFC_NNAME_H   
#include "nname.h"  //also includes nstring.h, lnfcdefs.h, smartptr.h, cstring.h
#endif


__LNFC_NAMESPACE_BEGIN__


// forward references //
class Database_path;


// Simplify typecast macros //
#define  dbPATH     (Database_path)
#define  dbPATHSTR  dbPATH nSTR


//---------------------------------------------------------------------


class Database_path_d : public Notes_string_d
{

protected:

    friend Database_path;

    Database_path_d(const Notes_string_d &s)
      : Notes_string_d(s)
    { }

    Database_path_d(const Notes_string *const filepath_addr,
                    const Notes_name   *const servername_addr = 0,
                    const Notes_string *const portname_addr = 0);

    Database_path_d(const Database_path_d &dbpath)
      : Notes_string_d(dbpath)
    { }

public:

    Notes_name    server();
    Database_path filepath();
    Notes_string  port();

    Notes_string  absolute();

    bool          is_local()   { return server()->is_empty(); }
    bool          is_remote()  { return !is_local(); }
};


//---------------------------------------------------------------------


class Database_path : public Smart_pointer2<Notes_string, Database_path_d>
{

public:

    Database_path(const Notes_string &dbpath)
      : SmPtr2(reinterpret_cast<Database_path_d*>(&*dbpath))
    { }

    Database_path(const Notes_string &filepath,
                  const Notes_name   &servername)
      : SmPtr2(new Database_path_d(&filepath, &servername))
    { }

    Database_path(const Notes_string &filepath,
                  const Notes_name   &servername,
                  const Notes_string &portname)
      : SmPtr2(new Database_path_d(&filepath, &servername, &portname))
    { }

    Database_path(const Database_path &dbpath)
      : SmPtr2(&*dbpath)
    { }

protected:

    friend Database_path_d;

    // this constructor is used by Database_path_d::absolute()
    Database_path(Database_path_d *dbpath_addr)
      : SmPtr2(dbpath_addr)
    { }

};


//---------------------------------------------------------------------

__LNFC_NAMESPACE_END__

#endif  // __LNFC_DBPATH_H

// EOF //
