//
//  document.h  -- part of LNFC library
//
//  Declaration of class Document, Document_d
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_DOCUMENT_H
#define __LNFC_DOCUMENT_H


#ifndef __LNFC_DATABASE_H   // also includes dbpath.h, nobject.h, etc.
#include "database.h"
#endif


__LNFC_NAMESPACE_BEGIN__


// ordinary datatypes //
typedef unsigned int   open_flags_t;
typedef unsigned int   update_flags_t;
typedef unsigned short encryption_flags_t;
typedef unsigned short decryption_flags_t;

// forward references //
class Document;

class Database;
class Form;
class Encryption_key;


//---------------------------------------------------------------------


class Document_d : public Notes_object_d
{
    protected:
	friend Document;

	Document_d(const Database &db, noteid_t noteid, bool open_now = true);
	Document_d(const Database &db);    // creates new note

	// args order is changed for preventing ambiguity
	Document_d(notes_handle_t already_existing_handle, const Database &db);

	virtual ~Document_d() { cleanup(); }

    public:
	int open(open_flags_t open_flags = 0);
	int create();
	virtual int close(bool force = false);
	virtual int save(bool force = false);
	int save(update_flags_t update_flags = 0);
	virtual int remove(bool force = false);
	int remove(update_flags_t update_flags = 0);
	virtual bool exist() { return is_open() || (noteid != 0); }

    public:
	int is_correct();
	int compute_with_form();
	int compute_with_form(const Notes_string &form_name);

	Document create_copy();
	Document create_encrypted_copy();

	int decrypt(const Encryption_key &key, decryption_flags_t flags = 0);
	int sign(bool skip_unsigned = true);
	int unsign();
	int check_signed();  // 1 = signed, 0 = unsigned, <0 = error
	bool is_signed();

	noteid_t get_noteid() { return noteid; }

    private:
	Database db;
	noteid_t noteid;

	int compute_with_form(const Document &form);
	int create_copy(notes_handle_t &created_handle);
	int create_encrypted_copy(notes_handle_t &created_handle);
};


//---------------------------------------------------------------------


class Document : public Smart_pointer<Document_d>
{
    public:
	Document(const Database &db, noteid_t noteid, bool open_now = true)
		: SmPtr(new Document_d(db, noteid, open_now)) {}

	Document(const Database &db)
		: SmPtr(new Document_d(db)) {}  // create new note

	// args order is changed for preventing ambiguity
	Document(notes_handle_t already_existing_handle, const Database &db)
		: SmPtr(new Document_d(already_existing_handle, db)) {}

    protected:
	//* Document(Document_d *doc_addr) : SmPtr(doc_addr)   { }

    public:
	static Document none(notes_status_t status = 0);
};


//---------------------------------------------------------------------

__LNFC_NAMESPACE_END__

#endif  // __LNFC_DOCUMENT_H

// EOF //
