//
//  field.h  --  part of LNFC library
//
//  Declaration of class Field, Field_d, Field_flags
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_FIELD_H
#define __LNFC_FIELD_H


#ifndef __LNFC_DOCUMENT_H
#include "document.h"
#endif


#ifndef __LNFC_TIMEDATE_H
#include "timedate.h"
#endif


__LNFC_NAMESPACE_BEGIN__


// ordinary datatypes //
typedef unsigned short item_flags_t;       // WORD
typedef unsigned short item_type_t;        // WORD
typedef unsigned long  field_flags_t;      // HIWORD = item_flags (ITEM_xxx),
                                           // LOWORD = item_type  (TYPE_xxx)
const char std_list_separator = ';';


// forward references //
class Field;

class Notes_string;
class Document;


//---------------------------------------------------------------------


struct Field_flags : public Initially_zero<field_flags_t>
{
    Field_flags(item_flags_t item_flags, item_type_t item_type)
      : Initially_zero<field_flags_t>(mkdword(item_flags, item_type))
    { }
    
    Field_flags(field_flags_t field_flags)
      : Initially_zero<field_flags_t>(field_flags)
    { }

    item_flags_t get_item_flags() { return hiword(value); }

    item_flags_t get_item_type()  { return loword(value); }
};


//---------------------------------------------------------------------


class Field_d : public Notes_object_d
{

protected:

    friend Field;

    Field_d(const Document &doc, const Notes_string &field_name);

    virtual ~Field_d() { cleanup(); }

public:

    virtual int assign(const Notes_string &new_value);
    virtual int assign(double new_value);
    virtual int assign(const Timedate &timedate);

    virtual int create(Field_flags field_flags, const Notes_string &new_value);
    virtual int create(Field_flags field_flags, double new_value);
    virtual int create(Field_flags field_flags, const Timedate &timedate);

    virtual bool is_open()  { return doc->is_open(); }

    virtual bool exist();

    virtual int remove();

    int  add_line(const Notes_string &line, bool allow_duplicates = false);
    int  remove_line(const Notes_string &line);
    int  lines_count();
    bool contains_line(const Notes_string &line);

    // if linenum is >= 0, return selected line of multi-line text field.
    // otherwise if list_separator is \0, return field contents in binary form.
    // otherwise return field contents in readable form as list of separated lines.
    Notes_string line(int linenum, char /* list_separator */ = 0);

    Notes_string text(char list_separator = std_list_separator) {
        return line(-1, list_separator);
    }

    Notes_string raw_text() {
        return line(-1, '\0');
    }

    double value(double default_value = 0.0);

    long ordinal_value(long default_value = 0L);

    Timedate timedate_value();

private:

    Document doc;

    Notes_string field_name;
};


//---------------------------------------------------------------------


class Field : public Smart_pointer<Field_d>
{

public:

    Field(const Document &doc, const Notes_string &field_name)
      : SmPtr(new Field_d(doc, field_name))
    { }

 // Field & operator = (const Notes_string &s) {
 //     associated_object->assign(s);
 //     return *this;
 // }

    Field & operator = (const Notes_string &s) {
        associated_object->assign(s);
        return *this;
    }

    Field & operator = (double d) {
        associated_object->assign(d);
        return *this;
    }

    operator Notes_string() { return associated_object->text(); }

    operator double()       { return associated_object->value(); }

    operator long()         { return associated_object->ordinal_value(); }

public:

    static const Field_flags TEXT;
    static const Field_flags LIST;
    static const Field_flags NAMES;
    static const Field_flags AUTHORS;

};


//---------------------------------------------------------------------

#endif  // __LNFC_FIELD_H

__LNFC_NAMESPACE_END__

// EOF //
