//
//  formula.cpp  --  part of LNFC library
//
//  Implementation of Formula class
//
//  Written by Evseev at Jun 2001
//

#include "formula.h"

#include "nstring.h"

#include "_lnfc.h"

#include <nsferr.h>     // ERR_HDL_NULL, used by RETURN_IF_NULL_HANDLE()
#include <nsfsearc.h>   // NSFSearch, NSFFormulaCompile
#include <osmem.h>      // OSMemFree

#include <stdio.h>	// snprintf


__LNFC_NAMESPACE_BEGIN__


int Formula_d::compile(const Notes_string &s)
{
    FORMULAHANDLE formula_handle;    
    WORD ignored;
    STATUS status;

    if (NSFFormulaCompile(
            NULL,               // name of formula (none)
            0,                  // length of name
            s->plain(),         // the ASCII formula
            s->length(),        // length of ASCII formula
            &formula_handle,    // result: handle to compiled formula
            &ignored,           // result: compiled formula length
            &status,            // return code from compile
            &eline, &epos, &eoffset, &elength
        ) != NOERROR)
    {
        RETURN_API_ERROR(status);
    }

    handle = (notes_handle_t)formula_handle;
    return 0;
}


int Formula_d::close(bool)
{
    reset();
    RETURN_IF_NULL_HANDLE();
    return status2int(OSMemFree((FORMULAHANDLE)handle));
}


string Formula_d::error_string(const char *what)
{
    string s = Notes_object_d::error_string(what);
    if (ok())
        return s;
    char info[128];
    snprintf(info, sizeof(info)-1, " (line %d, pos %d, offset %d, length %d)",
        eline, epos, eoffset, elength);
    return s + info;
}


__LNFC_NAMESPACE_END__

// EOF
