//
//  formula.h  --  part of LNFC library
//
//  Declaration of class Formula, Formula_d
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_FORMULA_H
#define __LNFC_FORMULA_H


#ifndef __LNFC_NOBJECT_H
#include "nobject.h"
#endif


__LNFC_NAMESPACE_BEGIN__


// forward references //
class Formula;

class Notes_string;


// ordinary datatypes //
typedef unsigned short notes_pos_t;    // WORD


//---------------------------------------------------------------------


class Formula_d : public Notes_object_d
{

protected:

    friend Formula;

    Formula_d(const Notes_string &s) {
        compile(s);
    }

    virtual ~Formula_d() { cleanup(); }

    virtual int close(bool _unused_force = false);

public:

    notes_pos_t error_line()   { return eline; }

    notes_pos_t error_pos()    { return epos; }

    notes_pos_t error_offset() { return eoffset; }

    notes_pos_t error_length() { return elength; }

    virtual string error_string(const char *what);

private:

    int compile(const Notes_string &s);

    notes_pos_t eline;   // compile error info
    notes_pos_t epos;
    notes_pos_t eoffset;
    notes_pos_t elength;

};


//---------------------------------------------------------------------


class Formula : public Smart_pointer<Formula_d>
{

public:

    Formula(const Notes_string &s)
      : SmPtr(new Formula_d(s))
    { }

};


//---------------------------------------------------------------------

#endif  //  __LNFC_FORMULA_H

__LNFC_NAMESPACE_END__

// EOF //
