/*
 *  itemtbl.c
 *
 *  Routines for parsing ITEM_TABLE
 */

#include <string.h>   /* strlen() */
#include <mem.h>      /* memcmp() */

#include <global.h>   /* USHORT */
#include <ods.h>      /* ODSLength() */
#include <nsfdata.h>  /* ITEM_TABLE, TYPE_TEXT */


void *get_summary_item(ITEM_TABLE *summary, char *item_name,
    USHORT *ptype, int *psize)
{
    int i, nitems, namelen = strlen(item_name);
    USHORT *psizes, *pnamesize, *pvalsize;
    char *pvalues;
    char *name;
    USHORT datatype;
    void *value;

    if (!summary || !item_name)
        return NULL;

    nitems = summary->Items;
    psizes = (USHORT*)( ((char*)summary) + ODSLength(_ITEM_TABLE) );
    pvalues = ((char*)psizes) + nitems * sizeof(USHORT) * 2;

    pnamesize = psizes;
    name = pvalues;
    for (i = 0; i < nitems; i++) {
        pvalsize = pnamesize + 1;
        datatype = *(USHORT*)(name + *pnamesize);
        value = name + *pnamesize + sizeof(USHORT);
        if ((!ptype || (!*ptype || *ptype == datatype)) &&
            (*pnamesize == namelen) &&
            !memcmp(name, item_name, namelen))
        {
            if (ptype)
                *ptype = datatype;
            if (psize)
                *psize = *pvalsize - sizeof(USHORT);
            return value;
        }
        name += *pnamesize + *pvalsize;
        pnamesize += 2;
    }
    return NULL;
}


char *get_summary_textitem(ITEM_TABLE *summary, char *item_name, char *dest_str)
{
    USHORT dtype = TYPE_TEXT;
    int len;
    void *p = get_summary_item(summary, item_name, &dtype, &len);
    if (!p)
        return NULL;
    if (dest_str) {
        memcpy(dest_str, p, len);
        dest_str[len] = 0;
        return dest_str;
    }
    return (char*)p;
}


char *get_summary_filepath(ITEM_TABLE *summary, char *dest_str) {
    return get_summary_textitem(summary, "$Path", dest_str);
}


bool is_directory_summary(ITEM_TABLE *summary)
{
    USHORT dtype = TYPE_TEXT;
    int len;
    void *p = get_summary_item(summary, "$Type", &dtype, &len);
    return p && (len == 4) && !memcmp(p, "$DIR", len);
}

/* EOF */
