#
#  Makefile  --  part of LNFC library
#
#  Rules for building LNFC using GCC under GNU/Linux
#
#  Written at Aug 2001 by Evseev
#

CC = c++
CPPFLAGS = -g -I/opt/lotus/notesapi/include -D__CONSOLE__

LD = c++
LDFLAGS  = -g -lnotes

.cpp.o:
	$(CC) -c $(CPPFLAGS) $<

test : nstring_test \
       dbpath_test \
       database_test \
       document_test \
       formula_test \
       field_test \
       directory_test \
       adrbook_test \
       abooks_test

lib :  nobject.o \
       nstring.o \
       nname.o \
       dbpath.o \
       database.o \
       document.o \
       timedate.o \
       field.o \
       formula.o \
       adrbook.o \
       abooks.o \
       location.o \
       adminrq.o \
       acl.o \
       notesini.o \
       directory.o \
       view.o
	echo Not implemented!

clean:
	rm *.o

cleanall: clean
	rm *_test

LIB_H = _lnfc.h
TST_H = nsession.h

LNFCDEFS_H = lnfcdefs.h smartptr.h

NOBJECT_H         = nobject.h   $(LNFCDEFS_H) _cstring.h bitricks.h
nobject.o         : nobject.cpp $(NOBJECT_H)
NOBJECT_OBJ       = nobject.o
                  
nsession.o        : nsession.cpp nsession.h $(LIB_H)

NSTRING_H         = nstring.h         $(LNFCDEFS_H) _cstring.h
ALL_NSTRING_H     = $(NSTRING_H) nname.h dbpath.h
nstring.o         : nstring.cpp         $(ALL_NSTRING_H) $(LIB_H) 
nstring_test.o    : nstring_test.cpp    $(ALL_NSTRING_H) $(TST_H) 
NSTRING_OBJ       = nstring.o nsession.o
nstring_test      : nstring_test.o  $(NSTRING_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@

NNAME_H           = nname.h           $(NSTRING_H)
nname.o           : nname.cpp           $(NNAME_H)     $(LIB_H)
nname_test.o      : nname_test.cpp      $(NNAME_H)     $(TST_H)
NNAME_OBJ         = nname.o         $(NSTRING_OBJ)
nname_test        : nname_test.o      $(NNAME_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@
                                               
DBPATH_H          = dbpath.h          $(NNAME_H)
dbpath.o          : dbpath.cpp          $(DBPATH_H)    $(LIB_H)     
dbpath_test.o     : dbpath_test.cpp     $(DBPATH_H)    $(TST_H)     
DBPATH_OBJ        = dbpath.o        $(NNAME_OBJ)
dbpath_test       : dbpath_test.o     $(DBPATH_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@
          
DATABASE_H        = database.h        $(DBPATH_H)
database.o        : database.cpp        $(DATABASE_H)  $(LIB_H)   
database_test.o   : database_test.cpp   $(DATABASE_H)  $(TST_H)   
DATABASE_OBJ      = database.o      $(DBPATH_OBJ)       nobject.o
database_test     : database_test.o   $(DATABASE_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@
        
DOCUMENT_H        = document.h        $(DATABASE_H)
document.o        : document.cpp        $(DOCUMENT_H)  $(LIB_H)   
document_test.o   : document_test.cpp   $(DOCUMENT_H)  $(TST_H) formula.h field.h
DOCUMENT_OBJ      = document.o      $(DATABASE_OBJ)
document_test     : document_test.o   $(DOCUMENT_OBJ)   formula.o field.o
	$(LD) $(LDFLAGS) $^ -o $@
        
TIMEDATE_H        = timedate.h
timedate.o        : timedate.cpp        $(TIMEDATE_H)  $(LIB_H)
timedate_test.o   : timedate_test.cpp   $(TIMEDATE_H)  $(TST_H)
TIMEDATE_OBJ      = timedate.o
timedate_test     : timedate_test.o   $(TIMEDATE_OBJ) nsession.o
	$(LD) $(LDFLAGS) $^ -o $@

FIELD_H           = field.h           $(DOCUMENT_H)
field.o           : field.cpp           $(FIELD_H)     $(LIB_H)      
field_test.o      : field_test.cpp      $(FIELD_H)     $(TST_H)      
FIELD_OBJ         = field.o         $(DOCUMENT_OBJ) timedate.o
field_test        : field_test.o      $(FIELD_OBJ)  formula.o
	$(LD) $(LDFLAGS) $^ -o $@
         
FORMULA_H         = formula.h         $(NOBJECT_H)
formula.o         : formula.cpp         $(FORMULA_H)   $(LIB_H)    
formula_test.o    : formula_test.cpp    $(FORMULA_H)   $(TST_H)  $(DOCUMENT_H)
FORMULA_OBJ       = formula.o       $(DATABASE_OBJ)
formula_test      : formula_test.o    $(FORMULA_OBJ)           document.o
	$(LD) $(LDFLAGS) $^ -o $@
       
ABOOKS_H          = abooks.h          $(DOCUMENT_H)
abooks.o          : abooks.cpp          $(ABOOKS_H) $(LIB_H) formula.h   _vector.h
abooks_test.o     : abooks_test.cpp     $(ABOOKS_H) $(TST_H)   field.h    directory.h
ABOOKS_OBJ        = abooks.o        $(DOCUMENT_OBJ)        formula.o
abooks_test       : abooks_test.o     $(ABOOKS_OBJ)          field.o  directory.o
	$(LD) $(LDFLAGS) $^ -o $@
                                 
DIRECTORY_H        = directory.h      $(DATABASE_H)
directory.o        : directory.cpp      $(DIRECTORY_H) $(LIB_H) $(FIELD_H) _fileops.h itemtbl.c
directory_test.o   : directory_test.cpp $(DIRECTORY_H) $(TST_H)
DIRECTORY_OBJ      = directory.o    $(DATABASE_OBJ)
directory_test     : directory_test.o $(DIRECTORY_OBJ) document.o field.o
	$(LD) $(LDFLAGS) $^ -o $@
                                               
ADRBOOK_H         = adrbook.h         $(DATABASE_H)
adrbook.o         : adrbook.cpp         $(LIB_H) $(ADRBOOK_H) $(FIELD_H) $(DIRECTORY_H)
adrbook_test.o    : adrbook_test.cpp    $(TST_H) $(ADRBOOK_H) $(FIELD_H) $(DIRECTORY_H)
ADRBOOK_OBJ       = adrbook.o       $(DIRECTORY_OBJ) field.o document.o
adrbook_test      : adrbook_test.o    $(ADRBOOK_OBJ) abooks.o formula.o 
	$(LD) $(LDFLAGS) $^ -o $@

LOCATION_H        = location.h        $(DOCUMENT_H)
location.o        : location.cpp        $(LIB_H) $(LOCATION_H) adrbook.h formula.h
                                               
NOTESINI_H        = notesini.h        $(NOBJECT_H) nstring.h
notesini.o        : notesini.cpp        $(LIB_H) $(NOTESINI_H) field.h $(LOCATION_H) directory.h
NOTESINI_OBJ      : notesini.o      $(FIELD_OBJ) location.o directory.o

ADMINRQ_H         = adminrq.h         $(DATABASE_H)
adminrq.o         : adminrq.cpp         $(LIB_H) $(ADMINRQ_H)
adminrq_test.o    : adminrq_test.cpp    $(TST_H) $(ADMINRQ_H)
ADMINRQ_OBJ       = adminrq.o       $(DATABASE_OBJ)
adminrq_test      : adminrq_test.o    $(ADMINRQ_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@

ACL_H             = acl.h             $(DATABASE_H)
acl.o             : acl.cpp             $(LIB_H) $(ACL_H)
acl_test.o        : acl_test.cpp        $(TST_H) $(ACL_H)
ACL_OBJ           = acl.o           $(DATABASE_OBJ)
acl_test          : acl_test.o        $(ACL_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@

VIEW_H            = view.h            $(FIELD_H)
view.o            : view.cpp            $(LIB_H) $(VIEW_H)
view_test.o       : view_test.cpp       $(TST_H) $(VIEW_H)
VIEW_OBJ          = view.o          $(FIELD_OBJ)
view_test         : view_test.o       $(VIEW_OBJ)
	$(LD) $(LDFLAGS) $^ -o $@

DBCAT_H           = dbcat.h           $(DATABASE_H)
                                      
NOTESINI_H        = notesini.h        $(NOBJECT_H)
                                      
USER_ID_H         = user_id.h         $(NOBJECT_H)

lnfc_test.o       : lnfc_test.cpp  $(LNFC_H)
                                   
migrate.o         : migrate.cpp    $(LNFC_H)
