//
//  location.h  --  part of LNFC library
//
//  Declaration of class Location, Location_d
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_LOCATION_H
#define __LNFC_LOCATION_H


#ifndef __LNFC_DOCUMENT_H
#include "document.h"   //also includes nstring.h
#endif


__LNFC_NAMESPACE_BEGIN__


// ordinary datatypes //
typedef unsigned int notes_location_t;


// forward references //
class Location;

class Address_book;


//---------------------------------------------------------------------


class Location_d : public Document_d
{

protected:

    friend Location;

    Location_d(const Address_book &ab,
               const Notes_string &name,
               notes_location_t type,
               bool open_now = true);
    
    Location_d(const Address_book &ab,
               notes_location_t type,
               bool open_now = true);

public:

    virtual int create(const Notes_string &server_name,
                       int type,
                       const Notes_string &mailbox_filename);

    virtual int create_from(const Location &another_location,
                            const Notes_string &server_name);
};


//---------------------------------------------------------------------


class Location : public Smart_pointer2<Document, Location_d>
{

public:

    Location(const Address_book &ab, const Notes_string &name, int type, bool open_now = true)
      : SmPtr2(new Location_d(ab, name, type, open_now))
    { }

    Location(const Address_book &ab, int type, bool open_now = true)
      : SmPtr2(new Location_d(ab, type, open_now))
    { }

    static const notes_location_t LAN;
    static const notes_location_t MODEM;
    static const notes_location_t MODEM_AND_LAN;
    static const notes_location_t NO_CONNECT;

};


//---------------------------------------------------------------------

__LNFC_NAMESPACE_END__

#endif  // __LNFC_LOCATION_H

// EOF //
