/*
 *  migrate.cpp
 *
 */

#include "_common.c"

#define NOT_IMPLEMENTED(x)


/*-------------------------------------------------------------
 *  Common variables
 */
enum { ADDITIONAL_SERVER, MAIN_SERVER, DISABLE_SERVER }
    dest_server_level;

enum { CREATE_IT, AVOID_IT, SKIP_IT }
    on_missing_field;

enum { ADD_IT, REPLACE_IT, SKIP_IT }
    on_missing_value;

    Notes_string  src_server_name;
    Notes_string  dest_server_name;

            bool  onthe_src_server;
            bool  onthe_dest_server;

  Admin_requests  adminrq;
Database_catalog  dbcat;


/*-------------------------------------------------------------
 * fixup_pubnames_person  : called from migrate_person
 *
 * Modifies "DeploymentServers" and "MailServer" fields
 * of given person record in Public Address Book (PAB).
 *
 * Returns: false(0) = stop migration
 *          true(1) = continue migration
 *          negative(<0) = error, stop migration
 */
int fixup_pubnames_person(Document &person)
{
    Field depsrv(person, "DeploymentServers");
    Field mailsrv(person, "MailServer");

    //  fixup "DeploymentServers" field
    //
    switch (dest_server_level) {
        case MAIN_SERVER:
        case ADDITIONAL_SERVER: {
            if (!depsrv.exist()) {
                switch (on_missing_field) {
                    case CREATE_IT:
                        depsrv.create(Field::TEXT  | Field::LIST |
                                      Field::NAMES | Field::AUTHORS);
                        depsrv.add_line(dest_server_name);
                        break;
                    case AVOID_IT:
                        break;
                    case SKIP_IT:
                    default:
                        return false;
                }
            } else if (!depsrv.contains(dest_server_name) {
                switch (on_missing_value) {
                    case REPLACE_IT:
                        depsrv.delete_line(mailsrv);
                    case ADD_IT:
                        depsrv.add_line(dest_server_name);
                        break;
                    case SKIP_IT:
                    default:
                        return false;
                }
            }
            break;
        }
        case DISABLE_SERVER: {
            if (depsrv.exist()) {
                if (depsrv.contains_line(dest_server_name)) {
                    depsrv.delete_line(dest_server_name);
                }
            }
            break;
        }
    }  // switch (dest_server_level)

    //  fixup "MailServer" field
    //
    switch (dest_server_level) {
        case MAIN_SERVER: {
            if (mailsrv != dest_server_name)
                mailsrv = dest_server_name;
            break;
        }
        case ADDITIONAL_SERVER:
            if (mailsrv == dest_server_name) {
                if (depsrv.lines_count() <= 1) {
                    NOT_IMPLEMENTED("No more servers to be mailserver?!?");
                } else {
                    int i, n;
                    for (i = 0, n = depsrv.lines_count(); i < n; i++) {
                        Notes_string s = depsrv.line(0);
                        if (s != dest_server_name) {
                            mailsrv = s;
                            break;
                        }
                    }
                    if (i == n) {
                        NOT_IMPLEMENTED("No more servers to be mailserver?!?");
                    }
                }
            break;
        case DISABLE_SERVER: {
            if (mailsrv == dest_server_name) {
                if (depsrv.lines_count() <= 0) {
                    NOT_IMPLEMENTED("User may be removed completely?");
                    mailsrv = "";
                } else {
                    mailsrv = depsrv.line(0);
                }
            break;
        }
    }  // switch (dest_server_level)
}


/*-------------------------------------------------------------
 *  create_user_directory  : called from migrate_person()
 *
 *  If executed on the destination server, does following:
 *    - check \notes\data\users\person_lastname and create it, if not exist
 *    - if USER.ID is not found, try to extract it from Mail Stats database
 *    - if USER.ID0 (backup copy of USER.ID) is not found, create it
 *
 *  If executed on the source server, does following:
 *    - send mail message with USER.ID
 *      to Mail Stats database of destination server
 */
int create_user_directory(Directory &userdir)
{
    if (onthe_dest_server) {
        if (!userdir.exist())
            userdir.create();
        User_id userid(userdir);
        bool must_be_validated = false;
        if (!userid.exist()) {
            if (userid.extract_from_stats())
                must_be_validated = true;
        }
        if (!userid.exist_copy()) {
            if (userid.create_copy())
                must_be_validated = true;
        }
        if (must_be_validated) {
            userdir.validate_perms();
        }
    } else if (onthe_src_server) {
        do {
            Personal_address_book pnab(userdir);
            // don't send USER.ID, if location for dest_server already exist in PNAB.
            if (pnab.exist()) {
                if (Location(pnab, dest_server_name, Location::LAN).exist())
                    break;  //leave do{}
            }
            User_id userid(userdir);
            if (userid.exist())
                userid.send_to(dest_server_name);
        }
    }
    return 0;
}


/*-------------------------------------------------------------
 *  validate_acl_and_create_remote_replica
 *    : callback, called from create_user_databases
 *
 */
typedef struct {
    Notes_string &deployment_servers;
    Notes_string &dest_server_name;
} Args_vaacrr;

int validate_acl_and_create_remote_replica(Database &db, void *args)
{
    Args_vaacrr *a = reinterpret_cast<Args_vaacrr*>(args));
    NOT_IMPLEMENTED("");
    return 0;
}


/*-------------------------------------------------------------
 *  create_user_databases  : called from migrate_person
 *
 *  If executed on the source server:
 *    For all databases of given person located on the local server
 *    (mailbox and \notes\data\users\personal_dir\*.nsf):
 *    validate ACL's and create replicas to destination server.
 *
 *  Otherwise (on the target or third-party server):
 *    ???
 */
int create_user_databases(Document &person, Directory &userdir)
{
    if (onthe_src_server) {
        Args_vaacrr a = { 
            Field(person, "DeploymentServers").text(),
            dest_server_name
        };
        if (userdir.exist())
            userdir.foreach_database(validate_acl_and_create_remote_replica, &a);
        Person_mailbox maildb(person);
        if (maildb.exist())
            validate_acl_and_create_remote_replica(maildb, &a);
    } else {
        NOT_IMPLEMENTED("create admin requests for creating remote replicas");
    }
    return 0;
}


/*-------------------------------------------------------------
 *  create_pnab_location  : called from migrate_person
 */
int create_pnab_location(Directory &userdir, Notes_string &mailbox_filename)
{
    Personal_address_book pnab(userdir);
    if (pnab.exist()) {
        Location dest_location(pnab, dest_server_name, Location::LAN);
        if (!dest_location.exist()) {
            Location another_location(pnab, Location::LAN);
            if (another_location.exist()) {
                dest_location.create_from(another_location, dest_server_name);
            } else {
                dest_location.create(dest_server_name, Location::LAN,
                    mailbox_filename);
            }
        }
        Notes_ini_file inifile(userdir);
        if (inifile.exist()) {
            inifile.set_location(dest_location);
        }
    }
    return 0;
}


/*-------------------------------------------------------------
 *  remove_pnab_location  : called from migrate_user
 */
int remove_pnab_location(Directory &userdir)
{
    if (onthe_dest_server)   // PNAB will be removed completely before
        return 0;            // any changes are replicated to another servers

    Personal_address_book pnab(userdir);
    if (pnab.exist()) {
        while(1) {
            Location dest_location(pnab, dest_server_name, Location::LAN);
            if (!dest_location.exist())
                break;
            dest_location.delete();
        }
    }
    return 0;
}


/*-------------------------------------------------------------
 *  remove_user_databases  : called from migrate_user
 */
int remove_user_databases(Directory &userdir, Notes_string &mailbox_filename)
{
    if (onthe_dest_server) {
        if (userdir.exist()) {
            userdir.foreach_database(delete_local_database);
        }
        Database maildb(mailbox_filename);
        if (maildb.exist()) {
            maildb.delete();
        }
    } else {
        if (dbcat.exist()) {
            dbcat.foreach_matching(
                NOT_IMPLEMENTED("(Server = \"" + dest_server_name + "\") & "
                                "@Begins(Filepath, \"" + userdir.text()"\")"),
                delete_remote_database);
        }
    }
    return 0;
}


/*-------------------------------------------------------------
 *  remove_user_directory  : called from migrate_person
 */
int remove_user_directory(Directory &userdir)
{
    if (userdir.exist()) {
        if (userdir.open_perms()) {
            userdir.delete();
        }
    }
    return 0;
}

/*-------------------------------------------------------------
 *  migrate_person  : called from main
 */
int migrate_person(Document &person)
{
    if (fixup_pubnames_person(person) != true)
        return 0;

    Directory userdir(person);
    Notes_string mailbox_filename = Field(person, "MailFile").text();

    switch (dest_server_level) {
        case MAIN_SERVER:
        case ADDITIONAL_SERVER: {
            create_user_directory(userdir);
            create_user_databases(person, userdir);
            create_pnab_location(userdir, mailbox_filename);
            break;
        }
        case DISABLE_SERVER: {
            remove_pnab_location(userdir);
            remove_user_databases(userdir, mailbox_filename);
            remove_user_directory(userdir);
            break;
        }
    }
    return 0;
}


int parse_command_line(int argc, char *argv[])
{
    NOT_IMPLEMENTED("");
    return 0;
}


int main (int argc, char *argv[])
{
    int i, n;

    String_collection person_names;

    parse_command_line(argc, argv);

    Init_Notes_runtime();

    build_person_list(&person_names);

    adminrq.init();
    dbcat.init();

    Address_books abooks;

    for (i = 0, n = person_names.count(); i < n; i++) {
        Document person = abooks.lookup_by_lastname(person_names.at(i));
        if (person.exist()) {
            migrate_person(person);
        } else {
            NOT_IMPLEMENTED("Display warning and process next user");
        }
    }

    return 0;
}

/* EOF */
