//
//  nobject.h  --  part of LNFC library
//
//  Declaration of class Notes_object, Notes_object_d.
//  Some basic datatypes and inline routines
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_NOBJECT_H
#define __LNFC_NOBJECT_H


#include "lnfcdefs.h"

#include "_cstring.h"


__LNFC_NAMESPACE_BEGIN__


// ordinary datatypes //
typedef unsigned long  notes_handle_t;   // HANDLE, DBHANDLE, ...
typedef unsigned short notes_status_t;   // STATUS


// forward references //
class Notes_object;


//---------------------------------------------------------------------

#include "bitricks.h"

inline int status2int(notes_status_t status) {
    return (status == 0) ? status : (((int)status) | msb_mask<int>());
}


//---------------------------------------------------------------------


class Notes_object_d : virtual public Self_destroyed
{

protected:

    friend Notes_object;

    Notes_object_d()
      : handle(0),
        last_error(0),
        _must_be_saved(true),
        _must_be_closed(true)
    { }

    Notes_object_d(notes_handle_t active_handle)
      : handle(active_handle),
        last_error(0),
        _must_be_saved(true),
        _must_be_closed(true)
    { }

    virtual ~Notes_object_d() {
        cleanup();
    }

    void cleanup() {
        if (_must_be_saved) save();
        if (_must_be_closed) close();
    }

public:

    virtual int close(bool force = false) { return 0; }

    virtual int save(bool force = false) { return 0; }

    bool must_be_saved(bool save_on_exit = true) {
        bool f = _must_be_saved;
        _must_be_saved = save_on_exit;
        return f;
    }

    bool must_be_closed(bool close_on_exit = true) {
        bool f = _must_be_closed;
        _must_be_closed = close_on_exit;
        return f;
    }

    bool dont_save(bool dont_save_on_exit = true)  {
        return must_be_saved(!dont_save_on_exit);
    }
                                            
    bool dont_close(bool dont_close_on_exit = true) {
        return must_be_closed(!dont_close_on_exit);
    }

public:    //---------  informational  ---------------

    virtual bool is_open()      { return (handle != 0); }

    virtual bool exist()        { return (handle != 0); }

    notes_handle_t get_handle() { return handle; }

    bool ok()         { return (last_error >= 0); }

    bool bad()        { return (last_error < 0); }

    bool ok(int i)    { return (i >= 0); }

    bool bad(int i)   { return (i < 0); }

    void reset(int new_value = 0) { last_error = new_value; }

    int get_last_error()          { return last_error; }

    virtual string error_string(const char *where);
    string error_string(const string where);

protected:

    bool _must_be_saved;
    bool _must_be_closed;

    notes_handle_t handle;

    int last_error;   // negative = error, zero = Ok,
                      // positive = ok with something additional info.

};


//---------------------------------------------------------------------


class Notes_object : public Smart_pointer<Notes_object_d>
{
protected:
    Notes_object() : SmPtr(0) { }  // required by GCC
};


//---------------------------------------------------------------------

__LNFC_NAMESPACE_END__

#endif  // __LNFC_NOBJECT_H

// EOF //
