//
//  notesini.cpp  --  part of LNFC library
//
//  Implementation of Notes_ini_d class
//
//  Written by Evseev at Jul 2001
//

#include "notesini.h"

#include "field.h"
#include "location.h"
#include "directory.h"    // ...also includes database.h

#if defined(_WIN32)
#  include <windows.h>    // Get:SetPrivateProfileString
#  include <strstream.h>  // ...must be before NotesAPI headers
#endif

#include "_lnfc.h"

#include <oserr.h>        // ERR_WRITETRUNC
#include <names.h>        // MAXPATH


Notes_ini_d::Notes_ini_d(const Directory &userdir)
  : filepath(userdir->expand("notes.ini"))
{
}


int Notes_ini_d::set_location(const Location &loc)
{

#if defined(_WIN32)

   const char *ini_filename = getpath()->native().c_str();
   noteid_t    loc_noteid = loc->get_noteid();
   noteid_t    ini_noteid = 0;
   char        text[MAXPATH];
   char        comment[MAXPATH];

   comment[0] = 0;

   if (GetPrivateProfileString("Notes", "Location",
       "", text, sizeof(text), ini_filename))
   {
       strstream sst(text, strlen(text));
       char      namestr[MAXPATH];
       char      idstr[3 * sizeof(noteid_t)];

       sst.get(namestr, sizeof(namestr), ',');
       if (sst.peek() == ',') sst.ignore();

       sst.get(idstr, sizeof(idstr), ',');
       if (sst.peek() == ',') sst.ignore();
    
       strstream(idstr, strlen(text)) >> ini_noteid;

       sst.get(comment, sizeof(comment));
   }

   if (ini_noteid != loc_noteid) {
       strstream sst;
       sst << Field(loc, "Name")->text()->native() << ","
           << hex << loc_noteid << ","
           << comment;
       if (!WritePrivateProfileString("Notes", "Location", sst.str(), ini_filename))
           RETURN_API_ERROR(ERR_WRITETRUNC);
       return (int)true;   // NOTES.INI changed
   }

#else

#  error  Access to INI-files is host dependent and must be implemented now

#endif

   return (int)false;   // NOTES.INI not changed

}

// EOF //
