//
//  nstring.cpp  --  part of LNFC library
//
//  Implementation of classes
//    - Notes_string
//    - Notes_name
//    - Database_path
//
//  Written by Evseev at Jun 2001
//

#include "nstring.h"
#include "nname.h"
#include "dbpath.h"

#include "bitricks.h"

#include "_lnfc.h"

#include <osmisc.h>    // OSTranslate
#include <osfile.h>    // OSPathNetConstruct
#include <names.h>     // MAXPATH

#if defined(__WIN32_CONSOLE__)    // CharToOemA
#  include <windows.h>
#  if defined(_MSC_VER)
#    pragma comment(lib,"user32.lib")
#  endif
#endif


__LNFC_NAMESPACE_BEGIN__


//---------------------------------------------------------------------


static char *new_lmbcs_cstr(const char *s)
{
    int bufsize = (strlen(s)+1) * 2;  // assume for russian (1 letter = 2 byte)
    char *buf;

    while(1) {
        if ((buf = new char[bufsize]) == 0)
            return 0;
        int len = OSTranslate( OS_TRANSLATE_NATIVE_TO_LMBCS,
                               (char *)s, strlen(s)+1,
                               buf, bufsize
                             );
        if ((len > 0) && (buf[len-1] == 0))
            break;
        delete buf;
        bufsize += bufsize;
    }

    return buf;
}


//---------------------------------------------------------------------


Notes_string::Notes_string(size_t len)
  : SmPtr(new Notes_string_d(len))
{ }

Notes_string::Notes_string(const char *s, size_t start, size_t len)
  : SmPtr(new Notes_string_d(new_lmbcs_cstr(s), start, len, true))
{ }

Notes_string::Notes_string(const char *s, bool, size_t start, size_t len)
  : SmPtr(new Notes_string_d(s, start, len, false))
{ }

Notes_string::Notes_string(const string &s, size_t start, size_t len)
  : SmPtr(new Notes_string_d(new_lmbcs_cstr(s.c_str()), start, len, true))
{ }

Notes_string::Notes_string(const string &s, bool, size_t start, size_t len)
  : SmPtr(new Notes_string_d(s.c_str(), start, len, false))
{ }


//---------------------------------------------------------------------


Notes_string& Notes_string::operator = (const char *s)
{
    if (s) {
        char *p = new_lmbcs_cstr(s);
        if (p) {
            associated_object->_release();
            associated_object = new Notes_string_d(p);
            delete p;
        }
    }
    return *this;
}


Notes_string operator+ (const Notes_string &s1, const Notes_string &s2)
{
    Notes_string result(s1->length() + s2->length());
    result->append(*s1);
    result->append(*s2);
    return result;
}


string Notes_string_d::native(bool must_be_prepared_for_console)
{
    char   buf[1024];
    char  *bufaddr = buf;
    size_t bufsize = sizeof(buf);
    size_t buflen;

    while (bufsize < max_possible_signed<unsigned int>()) {

#if defined(OS390) && (__STRING_CODE_SET__ != ISO8859-1)  // ebcdic compile

        buflen = OSLMBCSToNative(c_str(), MAXWORD, bufaddr, bufsize);

#else   // !if defined(OS390, ebcdic compile)

        buflen = OSTranslate(OS_TRANSLATE_LMBCS_TO_NATIVE,
            plain(), length(), bufaddr, bufsize-1);

#endif

        if (buflen < bufsize-1)  // buffer has enough size to store data
            break;
        if (bufaddr != buf)      // else delete old buffer and allocate new
            delete bufaddr;
        if ((bufaddr = new char[bufsize *= 2]) == 0)
            return "(text is too big: no more heap space!)";
    }

#if defined(__WIN32_CONSOLE__)
    if (must_be_prepared_for_console)
        CharToOemA(bufaddr, bufaddr);
#endif

    string s(bufaddr);
    if (bufaddr != buf)
        delete bufaddr;
    return s;
}


//---------------------------------------------------------------------


__LNFC_NAMESPACE_END__

// EOF
