//
//  nstring.h  --  part of LNFC library
//
//  Declaration of class Notes_string, Notes_string_d
//
//  Written by Evseev at Jul 2001
//

#ifndef __LNFC_NSTRING_H
#define __LNFC_NSTRING_H


#include "lnfcdefs.h"

#include "_cstring.h"


__LNFC_NAMESPACE_BEGIN__


// forward references //
class Notes_string;

class Notes_name_d;
class Database_path_d;


// Simplify typecast macros //
#define  nSTR  (Notes_string)


// Readable aliases for values of bool args //
const bool Skip_lmbcs_conversion = true;


//-------------------------------------------------------------


class Notes_string_d : virtual public Self_destroyed, public string
{

protected:

    // provide access to constructors
    friend Notes_string;

    Notes_string_d(size_t len)
      : string()
    {
        if (len > 0) reserve(len);
    }

    Notes_string_d(const char *s,
                   size_t start = 0,
                   size_t len = NPOS,
                   bool must_be_freed = false)
      : string(s, start, len)
    {
        if(must_be_freed) delete s;
    }

    // not required because not provides translating to LMBCS
    //Notes_string_d(string &s) : string(s) { }

    Notes_string_d(const Notes_string_d &s) : string(s) { }

public:

    bool is_empty() {
        return length() == 0;
    }
                                                           
    // There is compatibility hack for passing arguments to NotesAPI.
    // All they functions have 'char*' arguments declared without 'const' modifier.
    char *plain() {
        return (char*)c_str();
    }

    // returns natively encoded string for using by system I/O calls, etc.
    string native(bool must_be_prepared_for_console = false);

    // returns string for printing (differents from native under Win32 console)
    string readable() {
        return native(true);
    }
};


//-------------------------------------------------------------


class Notes_string : public Smart_pointer<Notes_string_d>
{

public:

    Notes_string(size_t len);

    Notes_string(const char   *s, size_t start = 0, size_t len = NPOS);

    Notes_string(const char   *s, bool anyway_skips_lmbcs_conversion,
                                  size_t start = 0, size_t len = NPOS);

    Notes_string(const string &s, size_t start = 0, size_t len = NPOS);

    Notes_string(const string &s, bool anyway_skips_lmbcs_conversion,
                                  size_t start = 0, size_t len = NPOS);

//* Notes_string::Notes_string(const Notes_string &s)
//*   : SmPtr(s.associated_object)
//* { }

    Notes_string &operator = (const char *s);

protected:

    friend Notes_string_d;

    Notes_string(Notes_string_d *str_addr)
      : SmPtr(str_addr)
    { }

};


//-------------------------------------------------------------


inline bool operator == (const Notes_string &s1, const Notes_string &s2) {
    return (*s1 == *s2);
}

inline bool operator != (const Notes_string &s1, const Notes_string &s2) {
    return !(s1 == s2);
}

Notes_string operator+ (const Notes_string &s1, const Notes_string &s2);


//-------------------------------------------------------------

__LNFC_NAMESPACE_END__

#endif  // __LNFC_NSTRING_H

// EOF //
