/*
 *  pre-defs.h  --  part of LNFC library
 *
 *  PURPOSE:
 *    This must be included AFTER headers of standard C API
 *    (otherwise, causes compile errors under Borland C++)
 *    and BEFORE any header of Notes API.
 *
 *  Used internally by LNFC only, not by user application,
 *  because userapp uses LNFC wrapper and not requires Notes API ;)
 *
 *  Written by Evseev at Jun 2001
 */

#ifndef __PREDEFS_H
#define __PREDEFS_H


//-------------------------------------------------------------
//
//  Platform detection macros
//
//  This must be BEFORE NotesAPI includes because NotesAPI requires W32 define
//

#if defined(_WIN32)
#  if !defined(W32)
#    define W32  1       /* required by NotesAPI */
#  endif
#  if !defined(__CONSOLE__) && !defined(__GUI__)
#    define __CONSOLE__ 1
#  endif
#  if defined(__CONSOLE__) && !defined(__WIN32_COMSOLE__)
#    define __WIN32_CONSOLE__ 1   /* my own macro */
#  endif
#endif 


//---------------------------------------------------------------------
//
//  Error checking for members of Notes_object child's
//
//  These macros cannot be implemented as inline functions,
//  so, use old good #define's
//

//
//   Terminate caller, if object is in erroneous state
//
#define RETURN_IF_ERROR() \
        do { if (bad()) return last_error; } while(0)

//
//   Set new last_error value and terminate caller
//   Doesn't check that new value is actually erroneous (don't calls bad())
//
#define RETURN_ERROR(__error_code) \
        do { reset(__error_code); return last_error; } while(0)

//
//   Call NotesAPI routine.
//   Save result to last_error.
//   Terminate caller, if error occured.
//
#define RETURN_IF_API_ERROR(__notes_api_call) \
        do { \
            last_error = status2int(__notes_api_call); \
            if (bad()) return last_error; \
        } while(0)

//
//   Inspire termination of caller with given error code (saved to last_error)
//   Doesn't check that new value is actually erroneous (don't calls bad())
//
#define RETURN_API_ERROR(__api_error_code) \
        return last_error = status2int(__api_error_code)

//
//   Call NotesAPI routine.
//   On error terminates caller WITHOUT setting 'last_error'.
//
#define __RETURN_IF_API_ERROR(__notes_api_call) \
        do { \
            STATUS status = __notes_api_call; \
            if (status != NOERROR) return status2int(status); \
        } while(0)


//---------------------------------------------------------------------
//
//  Lotus datatypes.
//  Must be included AFTER standard C headers because types/defines conflict
//  
#include <global.h>

#endif  /* ifndef __PREDEFS_H */

/* EOF */
