//
//  timedate.cpp  --  part of LNFC library
//
//  Implementation of Timedate class
//
//  Written by Evseev at Aug 2001
//

#include "_lnfc.h"

#include "timedate.h"

#include <global.h>
#include <ostime.h>  // OSCurrentTimeZone
#include <misc.h>    // TimeLocalToGM


Timedate::Timedate(notes_timedate_t &ntime)
{
    memcpy(&timedate, &ntime, sizeof(timedate));
}


int Timedate::setup(struct tm *systime)
{
    TIME notes_time;

    //  Convert time from the tm structure to a Notes TIME structure.
    //
    notes_time.year    = systime->tm_year + 1900;
    notes_time.month   = systime->tm_mon + 1;
    notes_time.day     = systime->tm_mday;
    notes_time.weekday = systime->tm_wday + 1;
    notes_time.hour    = systime->tm_hour;
    notes_time.minute  = systime->tm_min;
    notes_time.second  = systime->tm_sec;
    notes_time.hundredth = 0;

    //  Set time zone and Daylight Savings Time indicator.
    //
    OSCurrentTimeZone(&notes_time.zone, &notes_time.dst);

    //  Use the integer members of the TIME structure
    //  to construct the TIMEDATE
    //
    TimeLocalToGM(&notes_time);
    memcpy(&timedate, &notes_time.GM, sizeof(timedate));

    return 0;
}


time_t Timedate::systime()
{
    time_t t;
    struct tm systime;
    TIME notes_time;

    memcpy(&notes_time.GM, &timedate, sizeof(notes_time.GM));
    OSCurrentTimeZone(&notes_time.zone, &notes_time.dst);
    TimeGMToLocalZone(&notes_time);

    systime.tm_year = notes_time.year    - 1900;
    systime.tm_mon  = notes_time.month   - 1;
    systime.tm_mday = notes_time.day;
    systime.tm_wday = notes_time.weekday - 1;
    systime.tm_hour = notes_time.hour;
    systime.tm_min  = notes_time.minute;
    systime.tm_sec  = notes_time.second;

    return mktime(&systime);
}


string Timedate::strtime()
{
    char buf[MAXALPHATIMEDATE + 1];
    WORD buflen;

    if (NOERROR == ConvertTIMEDATEToText(
                   NULL,   // void *IntlFormat
                   NULL,   // TFMT *TextFormat
                   (TIMEDATE*)&timedate,
                   buf,
                   sizeof(buf),
                   &buflen))
    {
        buf[buflen] = 0;
    } else {
        buf[0] = 0;
    }
    return string(buf);
}


// EOF //
