//
//   view_test.cpp  --  optional part of LNFC library
//
//   Written by Evseev at Aug 2001
//

#include "view.h"
#include "field.h"

#include "nsession.h"  //also includes fstream.h



__LNFC_NAMESPACE_BEGIN__


void show_doc(const Document &doc, const Notes_string &field_name)
{
    if (doc->exist()) {
        Field f(doc, field_name);
        cout << " Found: \"" << f->text()->readable() << "\", "
             << " noteid = " << hex << doc->get_noteid() << endl;
    } else if (doc->bad()) {
        cout << doc->error_string("Document not found") << endl;
    }
}


int main(int argc, char *argv[])
{
    if ((argc < 4) || (argc > 6)) {
        cout << "Usage: view_test db view field [value [fieldnum]]" << endl;
        cout << "Example view_test names Servers ..ServerName.." << endl;
        return 1;
    }

    INIT_NOTES_RUNTIME();

    Database_path dbpath(argv[1]);
    Notes_string view_name(argv[2]);
    Notes_string field_name(argv[3]);

    Database db(dbpath);
    if (db->bad()) {
        cout << db->error_string("OpenDatabase") << endl;
        return 1;
    }

    View view(db, view_name);
    if (view->bad()) {
        cout << view->error_string("GetView") << endl;
        return 1;
    }

    int count = 0;

    if (argc <= 4) {
        while(1) {
            Document doc = view->next_document();
            if (view->is_end_reached())
                break;
            if (doc->bad()) {
                cout << doc->error_string("Document") << endl;
                break;
            }
            Field f(doc, field_name);
            cout << (++count) << " = \"" << f->text()->readable() << "\"" << endl;
        }
        
        cout << "----------------" << endl;
        
        int i;
        for (i = 0; i < count; i++) {
            Document doc = view->at(i);
            if (doc->bad()) {
                cout << doc->error_string("Document") << endl;
                break;
            }
            Field f(doc, field_name);
            cout << i << " = \"" << f->text()->readable() << "\"" << endl;
        }

    } else {

        Notes_string field_value(argv[4]);
        if (argc > 5) {
            int column = atoi(argv[5]);
            if (column > 0) {
                show_doc(view->lookup_by_column(column, field_value), field_name);
            } else {
                show_doc(view->lookup_by_field(argv[5], field_value), field_name);
            }
        } else {
            show_doc(view->lookup(field_value), field_name);
        }
    }

    return 0;
}


__LNFC_NAMESPACE_END__

// EOF //
